<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Spanish</translation>
    </message>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation>Sistema Libre de notificación para nuevos correos de Thunderbird.</translation>
    </message>
    <message>
        <source>Windows integration</source>
        <translation>Integrado con Windows</translation>
    </message>
    <message>
        <source>Select how to integrate the program in Windows.</source>
        <translation>Seleccionar cómo integrar el programa en Windows.</translation>
    </message>
    <message>
        <source>AutoRun</source>
        <translation>Ejecución automática</translation>
    </message>
    <message>
        <source>Automatically start ${PRODUCT_NAME} after login.</source>
        <translation>Empezar automáticamente ${PRODUCT_NAME} después del arranque.</translation>
    </message>
    <message>
        <source>Auto Update-Check</source>
        <translation>Autocomprobación de actualizaciones</translation>
    </message>
    <message>
        <source>Automatically search for updates of ${PRODUCT_NAME} at startup.</source>
        <translation>Buscar automáticamente actualizaciones de ${PRODUCT_NAME} al empezar.</translation>
    </message>
    <message>
        <source>Program Group Entry</source>
        <translation>Entrada en el Grupo del programa</translation>
    </message>
    <message>
        <source>Create a ${PRODUCT_NAME} program group under Start Menu > Programs.</source>
        <translation>Crear un Grupo de programa de ${PRODUCT_NAME} en el Menú de Inicio &gt; Programas.</translation>
    </message>
    <message>
        <source>Desktop Entry</source>
        <translation>Entrada en el Escritorio</translation>
    </message>
    <message>
        <source>Create a ${PRODUCT_NAME} icon on the Desktop.</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Escritorio.</translation>
    </message>
    <message>
        <source>Start Menu Entry</source>
        <translation>Entrada en el Menú de Inicio</translation>
    </message>
    <message>
        <source>Create a ${PRODUCT_NAME} icon in the Start Menu.</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Menú de Inicio.</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>Select translations for ${PRODUCT_NAME}. ${PRODUCT_NAME} will choose a translation based on the system language.</source>
        <translation>Seleccione idioma para ${PRODUCT_NAME}. ${PRODUCT_NAME} elegirá el idioma basandose en el idioma del sistema.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} User Settings</source>
        <translation>${PRODUCT_NAME} Preferencias del usuario</translation>
    </message>
    <message>
        <source>Your settings and configuration made within ${PRODUCT_NAME}.</source>
        <translation>Tus preferencias y configuraciones hechas con ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>License Agreement</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>Start ${PRODUCT_NAME}</source>
        <translation>Iniciar ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>Click uninstall to begin the process.</source>
        <translation>Pulsa en desinstalar para empezar el proceso.</translation>
    </message>
    <message>
        <source>Uninstalling previous version of ${PRODUCT_NAME}...</source>
        <translation>Desinstalando la versión previa de ${PRODUCT_NAME}...</translation>
    </message>
    <message>
        <source>Uninstalling the old ${PRODUCT_NAME} installation failed! Continuing will delete EVERYTHING in $3.</source>
        <translation>¡La desistalación de la versión antigua de ${PRODUCT_NAME} ha fallado! Continuar borrara TODO en $3.</translation>
    </message>
    <message>
        <source>Error executing uninstaller.</source>
        <translation>Error en la ejecución del desinstalador.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the installation.</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la instalación.</translation>
    </message>
    <message>
        <source>Closing process ${EXE_NAME}...</source>
        <translation>Cerrando proceso ${EXE_NAME}...</translation>
    </message>
    <message>
        <source>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the installation.</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la instalación.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the uninstall.</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the uninstall.</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>The setup of ${PRODUCT_NAME} is already running.
Please, close all instances of it and click Retry to continue, or Cancel to exit.</source>
        <translation>La configuracíon de ${PRODUCT_NAME} está en ejecución.
Por favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>The uninstall of ${PRODUCT_NAME} is already running.
Please, close all instances of it and click Retry to continue, or Cancel to exit.</source>
        <translation>La desinstalación de ${PRODUCT_NAME} está en ejecución.
Por favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>The install path must not contain any of:
${BAD_PATH_CHARS}</source>
        <translation>El direccitorio de instalación no debe contener:
${BAD_PATH_CHARS}</translation>
    </message>
    <message>
        <source>The install path contains a previously installed ${PRODUCT_NAME} version, which will be replaced.</source>
        <translation>El directorio de instalación contiene una versión previa instalada de ${PRODUCT_NAME}, que será reemplazada.</translation>
    </message>
    <message>
        <source>The install path is not empty, but it doesn't look like it contains a previous ${PRODUCT_NAME} installation. The content will get overwritten.</source>
        <translation>El directorio de instalación no está vacio, pero no parece que contenga una versión previa de ${PRODUCT_NAME}. El contenido será sobreescrito.</translation>
    </message>
    <message>
        <source>$0 (current user only)</source>
        <translation>$0 (solo el usuario actual)</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} ${VERSION} could not be fully installed.
Please, restart Windows and run the setup program again.</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo instalarse completamente.
Por favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} could not be fully installed.
Please, restart Windows and run the setup program again.</source>
        <translation>${PRODUCT_NAME} No pudo instalarse completamente.
Por favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} ${VERSION} could not be fully uninstalled.
Please, restart Windows and run the uninstaller again.</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo desinstalarse completamente.
Por favor, reinicie Windows y vuelva a ejecutar el programa de desinstalación de nuevo.</translation>
    </message>
    <message>
        <source>Error deleting file:

$0

Click Retry to try again, or
Cancel to stop the uninstall.</source>
        <translation>Error eleminando el fichero:

$0

Pulse Reintentar para volver a probar, o
Cancelar para parar la desinstalación.</translation>
    </message>
    <message>
        <source>Error deleting file $0</source>
        <translation>Error durante la eliminación del fichero $0</translation>
    </message>
    <message>
        <source>You are about to install the 32-bit version of ${PRODUCT_NAME} on your 64-bit Windows. There is a 64-bit version of ${PRODUCT_NAME} available for download.</source>
        <translation>Estás instalando una versión de 32 bit de ${PRODUCT_NAME} en un Windows a 64 bit. Hay una versión de 64 bit ${PRODUCT_NAME} disponible para descargar.</translation>
    </message>
    <message>
        <source>This installer contains the 64-bit version of ${PRODUCT_NAME}. Your computer is running a 32-bit version of Windows, which can not execute 64-bit programs. Please download the 32-bit installer of ${PRODUCT_NAME}.</source>
        <translation>El programa de instalación contiene una versión de 64 bit de ${PRODUCT_NAME}. Tu ordenador está ejecutando una versión de 32 bit de Windows, la cual no puede ejecutar programas 64 bit. Por favor, descarge la versión de 32 bit de ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>This program requires at least Windows ${MIN_WINDOWS_VER}.</source>
        <translation>El programa requiere al menos Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>Uninstalling ${PRODUCT_NAME} has been aborted. Please try again later.</source>
        <translation>La desinstalación de ${PRODUCT_NAME} ha sido abortada. Por favor, inténtelo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} settings</source>
        <translation>${PRODUCT_NAME} configuración</translation>
    </message>
    <message>
        <source>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</source>
        <translation>El desinstalador se ha iniciado con privilegios de administador pero parece ser no ser una instalación de ${PRODUCT_NAME} de administrador. ¿Quiere volver a ejecutar el desinstalador sin privilegios de administrador?</translation>
    </message>
    <message>
        <source>Opening $0 in default browser...</source>
        <translation>Abriendo $0 en su navegador por defecto...</translation>
    </message>
    <message>
        <source>Unable to find Visual C++ Runtime ${ARCH}.</source>
        <translation>No se ha podido encontrar Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>The following required component was not found on this computer:
Visual C++ Runtime ${ARCH}
Do you want to download the installer for the component?</source>
        <translation>No se ha podido encontrar el siguiente componente requerido en su sistema:
Visual C++ Runtime ${ARCH}
¿Quiere descargar el instalador de este componente?</translation>
    </message>
    <message>
        <source>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</source>
        <translation>Una vez completadas las descargas, por favor ejecute el instalador descargado. Cuando el instalador haya finalizado, pulse OK para comprobar el estado de la instalación de nuevo.</translation>
    </message>
    <message>
        <source>The required component was successfully detected on your computer.</source>
        <translation>El componente requerido ha sido detectado satisfactoriamente en su ordenador.</translation>
    </message>
    <message>
        <source>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</source>
        <translation>El componente requerido no ha sido encontrado en su ordenador. Por favor, busque online descargas de Visual C++ ${ARCH} para Visual Studio 2015 y superior.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} will not be able to run.</source>
        <translation>${PRODUCT_NAME} no podrá ser ejecutado.</translation>
    </message>
    <message>
        <source>${PRODUCT_NAME} will not be able to start because a required component is missing.</source>
        <translation>${PRODUCT_NAME} no podra iniciarse poruqe un componente requerido no está presente.</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation>Neerlandés</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Portugees</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>Español</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <source>Chinese (Simplified)</source>
        <translation>Chino (simplificado)</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>Checo</translation>
    </message>
</context>
</TS>
